@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(IO::Async::Notifier);
 
-our $VERSION = '1.000';
+our $VERSION = '2.000';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Net::Async::AMQP - provides client interface to AMQP using L<IO::Async>
 
 =head1 VERSION
 
-version 1.000
+version 2.000
 
 =head1 SYNOPSIS
 
@@ -72,6 +72,12 @@ RabbitMQ provides some additional features:
 
 =item * Consumer cancellation notification
 
+=item * Reject
+
+=item * TTL for message expiry
+
+=item * 255-level priorities
+
 =back
 
 =head2 Missing features
@@ -402,6 +408,7 @@ sub on_closed {
 	my $self = shift;
 	my $reason = shift // 'unknown';
 	$self->debug_printf("Connection closed [%s]", $reason);
+	delete $self->{connected};
 
 	for my $ch (grep $_, values %{$self->{channel_by_id}}) {
 		$ch->bus->invoke_event(
@@ -551,12 +558,25 @@ sub setup_connection {
 			my ($self, $frame) = @_;
 			my $method_frame = $frame->method_frame;
 			$self->debug_printf("OpenOk received");
+			$self->connected->done;
 			$self->bus->invoke_event(connected =>);
 		}
 	);
 	$self
 }
 
+=head2 connected
+
+Returns a L<Future> which will resolve when the MQ connection is ready
+for use.
+
+=cut
+
+sub connected {
+	my ($self) = @_;
+	$self->{connected} ||= $self->future(set_label => 'MQ connection');
+}
+
 =head2 next_channel
 
 Returns the next available channel ready for L</open_channel>.
@@ -1368,7 +1388,7 @@ specification into appropriate Perl methods and classes.
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
