@@ -1,5 +1,5 @@
 package Net::Async::AMQP::Channel;
-$Net::Async::AMQP::Channel::VERSION = '1.000';
+$Net::Async::AMQP::Channel::VERSION = '2.000';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::AMQP::Channel - represents a single channel in an MQ connection
 
 =head1 VERSION
 
-version 1.000
+version 2.000
 
 =head1 SYNOPSIS
 
@@ -306,6 +306,12 @@ fail messages sent to an exchange that do not have an appropriate binding)
 
 =item * priority - defaults to undef (none), use this to take advantage of RabbitMQ 3.5+ priority support
 
+=item * reply_to - which queue to reply to (used for RPC, default undef)
+
+=item * correlation_id - unique message ID (used for RPC, default undef)
+
+=item * delivery_mode - whether to persist message (default 1, don't persist - set to 2 for persistent, see also "durable" flag for queues)
+
 =back
 
 =cut
@@ -336,12 +342,10 @@ sub publish {
 			timestamp        => $args{timestamp} // time,
 			type             => Net::AMQP::Value::String->new($args{type} // ''),
 			user_id          => $self->amqp->user,
-#            headers          => {
-#                type => $args{type},
-#            },
-			delivery_mode    => 1,
+            headers          => $args{headers} || { },
+			delivery_mode    => $args{delivery_mode} // 1,
 			priority         => $args{priority} // 1,
-			correlation_id   => undef,
+			correlation_id   => $args{correlation_id},
 			expiration       => (
 				exists $args{expiration}
 				# This would seem to make more sense as a numeric value, but the spec
@@ -349,10 +353,11 @@ sub publish {
 				? Net::AMQP::Value::String->new($args{expiration})
 				: undef
 			),
-			message_id       => undef,
-			app_id           => undef,
-			cluster_id       => undef,
-			weight           => 0,
+			message_id       => $args{message_id},
+			app_id           => $args{app_id},
+			cluster_id       => $args{cluster_id},
+			reply_to         => $args{reply_to},
+			weight           => $args{weight} // 0,
 		);
 		$self->closure_protection($f);
 		$self->send_frame(
@@ -434,6 +439,69 @@ sub ack {
 	});
 }
 
+=head2 nack
+
+Negative acknowledgement for a specific delivery.
+
+Returns a L<Future> which will resolve with the
+channel instance once the operation is complete.
+
+ $ch->nack(
+  delivery_tag => 123,
+ ) ==> $ch
+
+=cut
+
+sub nack {
+	my $self = shift;
+	my %args = @_;
+
+	my $id = $self->id;
+	$self->future->on_done(sub {
+		my $channel = $id;
+		my $frame = Net::AMQP::Frame::Method->new(
+			method_frame => Net::AMQP::Protocol::Basic::Nack->new(
+			   # nowait      => 0,
+				delivery_tag => $args{delivery_tag},
+				multiple     => $args{multiple} // 0,
+				requeue      => $args{requeue} // 0,
+			)
+		);
+		$self->send_frame($frame);
+	});
+}
+
+=head2 reject
+
+Reject a specific delivery.
+
+Returns a L<Future> which will resolve with the
+channel instance once the operation is complete.
+
+ $ch->nack(
+  delivery_tag => 123,
+ ) ==> $ch
+
+=cut
+
+sub reject {
+	my ($self, %args) = @_;
+
+	my $id = $self->id;
+	$self->future->on_done(sub {
+		my $channel = $id;
+		my $frame = Net::AMQP::Frame::Method->new(
+			method_frame => Net::AMQP::Protocol::Basic::Reject->new(
+			   # nowait      => 0,
+				delivery_tag => $args{delivery_tag},
+				multiple     => $args{multiple} // 0,
+				requeue      => $args{requeue} // 0,
+			)
+		);
+		$self->send_frame($frame);
+	});
+}
+
 =pod
 
 Example output:
@@ -615,24 +683,42 @@ sub next_pending {
 	# First part of a frame. There's more to come, so stash a new future
 	# and return.
 	if($frame->isa('Net::AMQP::Frame::Header')) {
-		# Start with empty payload
-		$self->{incoming_message}{type} = $frame->header_frame->type;
+		# Properties are available directly from the header frame
+		my $hdr_frame = $frame->header_frame;
+		$self->{incoming_message}{type} = $hdr_frame->type;
+		$self->{incoming_message}{properties} = {
+			map {; $_ => scalar($hdr_frame->$_) } qw(
+				content_type 
+				content_encoding
+				delivery_mode
+				priority
+				correlation_id
+				reply_to
+				expiration
+				message_id
+				timestamp
+				user_id
+				app_id
+			)
+		};
 		if($frame->header_frame->headers) {
 			eval {
-				$self->{incoming_message}{type} = $frame->header_frame->headers->{type}
-					if exists $frame->header_frame->headers->{type};
+				#$self->{incoming_message}{type} = $frame->header_frame->headers->{type}
+				#	if exists $frame->header_frame->headers->{type};
+				# Shallow copy for local storage
+				$self->{incoming_message}{headers} = { %{$frame->header_frame->headers} };
 				1
 			} or $self->debug_printf("Unexpected exception while doing something: %s", $@);
+		} else {
+			$self->{incoming_message}{headers} = {};
 		}
 
-		# Messages may be empty - in this case we'd have no body frames at all, we're done already:
 		if($frame->body_size) {
+			# Stash the size so we can do some basic validation on the payload frames
 			$self->{incoming_message}{pending} = $frame->body_size;
 		} else {
-			$self->bus->invoke_event(
-				message => @{$self->{incoming_message}}{qw(type payload ctag dtag rkey)},
-			);
-			delete $self->{incoming_message};
+			# Messages may be empty - in this case we'd have no body frames at all, we're done already:
+			$self->deliver_current_message;
 		}
 
 		return $self;
@@ -655,10 +741,7 @@ sub next_pending {
 			return $self;
 		} else {
 			# We have a full message now - hand it over to the event bus
-			$self->bus->invoke_event(
-				message => @{$self->{incoming_message}}{qw(type payload ctag dtag rkey)},
-			);
-			delete $self->{incoming_message};
+			$self->deliver_current_message;
 			return $self;
 		}
 	}
@@ -668,7 +751,7 @@ sub next_pending {
 	if($type eq 'Basic::ConsumeOk') {
 		my $ctag = $method_frame->consumer_tag;
 		$self->{consumer_tags}{$ctag} = 1;
-	} elsif($type eq 'Basic::Cancel') {
+	} elsif($type eq 'Basic::Cancel' or $type eq 'Basic::CancelOk') {
 		my ($ctag) = ($method_frame->consumer_tag);
 		$self->debug_printf("Cancel $ctag");
 		$self->bus->invoke_event(
@@ -792,6 +875,14 @@ sub next_pending {
 	return $self;
 }
 
+sub deliver_current_message {
+	my $self = shift;
+	$self->bus->invoke_event(
+		message => @{$self->{incoming_message}}{qw(type payload ctag dtag rkey headers properties)},
+	);
+	delete $self->{incoming_message};
+}
+
 sub extract_published {
 	my ($self, $dtag, $multiple) = @_;
 	if($multiple) {
@@ -928,7 +1019,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
