@@ -1,5 +1,5 @@
 package Net::Async::AMQP::Queue;
-$Net::Async::AMQP::Queue::VERSION = '1.000';
+$Net::Async::AMQP::Queue::VERSION = '2.000';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Net::Async::AMQP::Queue - deal with queue-specific functionality
 
 =head1 VERSION
 
-version 1.000
+version 2.000
 
 =cut
 
@@ -196,13 +196,46 @@ The on_message callback receives the following named parameters:
 
 =item * type
 
-=item * payload
+=item * payload - scalar containing the raw binary data for this message
 
-=item * consumer_tag
+=item * consumer_tag - which consumer tag received this message
 
-=item * delivery_tag
+=item * delivery_tag - the delivery information for L<Net::Async::AMQP::Channel/ack>
 
-=item * routing_key 
+=item * routing_key - routing key used for this message
+
+=item * properties - any properties for the message
+
+=item * headers - custom headers
+
+=back
+
+Properties include:
+
+=over 4
+
+=item * correlation_id - user-specified ID that can be used to link related messages, see
+L<Net::Async::RPC::Client> for details.
+
+=item * reply_to - user-specified target queue to which any replies should be sent
+
+=item * content_type - payload format
+
+=item * content_encoding - any encoding applied to the payload (gzip etc.)
+
+=item * delivery_mode - delivery persistence - 1 for default, 2 for permanent
+
+=item * priority - message priority, ranges from 0..255
+
+=item * expiration - when this message (would have) expired
+
+=item * message_id - user-specified ID
+
+=item * timestamp - when the message was published, usually the time in seconds
+
+=item * user_id - custom user-id info
+
+=item * app_id - user-specified application information
 
 =back
 
@@ -222,14 +255,16 @@ sub consumer {
 		@ev = (
 			# Deliver any matching messages to our callback
 			message => sub {
-				my ($ev, $type, $payload, $incoming_ctag, $dtag, $rkey) = @_;
+				my ($ev, $type, $payload, $incoming_ctag, $dtag, $rkey, $headers, $properties) = @_;
 				return unless $incoming_ctag eq $ctag;
 				$on_message->(
 					type => $type,
 					payload => $payload,
 					consumer_tag => $ctag,
 					delivery_tag => $dtag,
-					routing_key => $rkey
+					routing_key => $rkey,
+					headers => $headers,
+					properties => $properties,
 				);
 			},
 			# Drop event handlers and call cancellation callback on cancel
@@ -495,7 +530,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
