@@ -1,5 +1,5 @@
 package Net::Async::AMQP::Server::Protocol;
-$Net::Async::AMQP::Server::Protocol::VERSION = '1.000';
+$Net::Async::AMQP::Server::Protocol::VERSION = '2.000';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ Net::Async::AMQP::Server::Protocol
 
 =head1 VERSION
 
-version 1.000
+version 2.000
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
